@@ -1,6 +1,7 @@
 #!/usr/bin/perl
 
 use strict;
+use Lemonldap::NG::Manager;
 use Lemonldap::NG::Manager::Sessions;
 use HTML::Template;
 
@@ -31,7 +32,7 @@ my $skin = $cgi->{managerSkin} or $cgi->abort('managerSkin is not defined');
 my $css = 'tree.css';
 my $css_theme = 'ui-lightness';
 my $skin_dir  = 'skins';
-my $main_dir  = $cgi->{managerHtdocsPath};
+my $main_dir  = $cgi->getApacheHtdocsPath;
 
 my $template = HTML::Template->new(
     filename          => "$main_dir/$skin_dir/$skin/sessions.tpl",
@@ -44,6 +45,8 @@ $template->param( TREE        => $cgi->tree() );
 $template->param( DIR         => "$skin_dir/$skin" );
 $template->param( CSS         => $css );
 $template->param( CSS_THEME   => $css_theme );
+$template->param( VERSION     => $Lemonldap::NG::Manager::VERSION );
+$template->param( LANG        => shift $cgi->{lang} );
 print $cgi->header('text/html; charset=utf-8');
 print $template->output;
 
