@@ -9,7 +9,7 @@ package Lemonldap::NG::Manager::_i18n;
 
 use strict;
 use AutoLoader qw(AUTOLOAD);
-our $VERSION = '1.2.2_01';
+our $VERSION = '1.4.0';
 
 ## @method string translate(string text,string lang)
 # Returns $text translated in $lang.
@@ -48,74 +48,90 @@ __END__
 
 sub en {
     return {
-        _auth                  => 'Authentication',
-        _authChoice            => 'Authentication choice',
-        _userDB                => 'User',
-        _passwordDB            => 'Password',
-        _issuerDB              => 'Issuer',
-        _timezone              => 'Time zone',
-        _session_id            => 'Session identifier',
-        _url                   => 'Origin URL',
-        _user                  => 'Login',
-        _password              => 'Password',
-        _utime                 => 'Session timestamp',
-        _lastAuthnUTime        => 'Authentication timestamp',
-        _idp                   => 'IDP EntityID',
-        _idpConfKey            => 'IDP configuration key',
-        _samlToken             => 'SAML token',
-        _lassoSessionDump      => 'Lasso session dump',
-        _lassoIdentityDump     => 'Lasso identity dump',
-        advancedParams         => 'Advanced parameters',
-        apacheParams           => 'Apache parameters',
-        apacheAuthnLevel       => 'Authentication level',
-        applicationList        => 'Categories and applications',
-        attributesAndMacros    => 'Attributes and macros',
-        authChoiceModules      => 'Allowed modules',
-        authChoiceParam        => 'URL parameter',
-        authentication         => 'Authentication module',
-        authenticationLevel    => 'Authentication level',
-        authenticationTitle    => 'Authentication',
-        AuthLDAPFilter         => 'Authentication filter',
-        authParams             => 'Authentication modules',
-        dbiAuthChain           => 'Chain',
-        dbiAuthLoginCol        => 'Login field name',
-        dbiAuthnLevel          => 'Authentication level',
-        dbiAuthPassword        => 'Password',
-        dbiAuthPasswordCol     => 'Password field name',
-        dbiAuthPasswordHash    => 'Hash scheme',
-        dbiAuthTable           => 'Authentication table',
-        dbiAuthUser            => 'User',
-        dbiConnection          => 'Connection',
-        dbiConnectionAuth      => 'Authentication process',
-        dbiConnectionUser      => 'User process',
-        dbiParams              => 'DBI parameters',
-        dbiPassword            => 'Password',
-        dbiPasswordMailCol     => 'Mail field name',
-        dbiSchema              => 'Schema',
-        dbiUserChain           => 'Chain',
-        dbiUserPassword        => 'Password',
-        dbiUserTable           => 'User table',
-        dbiUserUser            => 'User',
-        deleteNotification     => 'Mark notification as done',
-        deleteSession          => 'Delete session',
-        done                   => 'done',
-        CAS_authnLevel         => 'Authentication level',
-        CAS_CAFile             => 'CA file',
-        CAS_gateway            => 'Gateway authentication',
-        CAS_pgtFile            => 'PGT file',
-        CAS_proxiedServices    => 'Proxied services',
-        CAS_renew              => 'Renew authentication',
-        CAS_url                => 'Server URL',
-        casAccessControlPolicy => 'Access control policy',
-        casAttr                => 'CAS login',
-        casParams              => 'CAS parameters',
-        casStorage             => 'CAS sessions module name',
-        casStorageOptions      => 'CAS sessions module options',
-        cda                    => 'Multiple domains',
-        checkXSS               => 'Check XSS attacks',
-        clickHereToForce       => 'Click here to force',
-        choiceParams           => 'Choice parameters',
-        Configuration          => 'Configuration',
+        _auth                    => 'Authentication',
+        _authChoice              => 'Authentication choice',
+        _userDB                  => 'User',
+        _passwordDB              => 'Password',
+        _issuerDB                => 'Issuer',
+        _timezone                => 'Time zone',
+        _session_id              => 'Session identifier',
+        _url                     => 'Origin URL',
+        _user                    => 'Login',
+        _password                => 'Password',
+        _utime                   => 'Session timestamp',
+        _lastAuthnUTime          => 'Authentication timestamp',
+        _idp                     => 'IDP EntityID',
+        _idpConfKey              => 'IDP configuration key',
+        _samlToken               => 'SAML token',
+        _lassoSessionDump        => 'Lasso session dump',
+        _lassoIdentityDump       => 'Lasso identity dump',
+        advancedParams           => 'Advanced parameters',
+        apacheParams             => 'Apache parameters',
+        apacheAuthnLevel         => 'Authentication level',
+        applicationList          => 'Categories and applications',
+        attributesAndMacros      => 'Attributes and macros',
+        authChoiceModules        => 'Allowed modules',
+        authChoiceParam          => 'URL parameter',
+        authentication           => 'Authentication module',
+        authenticationLevel      => 'Authentication level',
+        authenticationTitle      => 'Authentication',
+        AuthLDAPFilter           => 'Authentication filter',
+        authParams               => 'Authentication modules',
+        browserIdAuthnLevel      => 'Authentication level',
+        browserIdAutoLogin       => 'Automatic login',
+        browserIdBackgroundColor => 'Background color',
+        browserIdParams          => 'BrowserIDParams',
+        browserIdSiteLogo        => 'Site Logo',
+        browserIdSiteName        => 'Site name',
+        browserIdVerificationURL => 'Verification URL',
+        dbiAuthChain             => 'Chain',
+        dbiAuthLoginCol          => 'Login field name',
+        dbiAuthnLevel            => 'Authentication level',
+        dbiAuthPassword          => 'Password',
+        dbiAuthPasswordCol       => 'Password field name',
+        dbiAuthPasswordHash      => 'Hash scheme',
+        dbiAuthTable             => 'Authentication table',
+        dbiAuthUser              => 'User',
+        dbiConnection            => 'Connection',
+        dbiConnectionAuth        => 'Authentication process',
+        dbiConnectionUser        => 'User process',
+        dbiExportedVars          => 'Exported variables',
+        dbiParams                => 'DBI parameters',
+        dbiPassword              => 'Password',
+        dbiPasswordMailCol       => 'Mail field name',
+        dbiSchema                => 'Schema',
+        dbiUserChain             => 'Chain',
+        dbiUserPassword          => 'Password',
+        dbiUserTable             => 'User table',
+        dbiUserUser              => 'User',
+        deleteNotification       => 'Mark notification as done',
+        deleteSession            => 'Delete session',
+        demoExportedVars         => 'Exported variables',
+        demoParams               => 'Demonstration parameters',
+        done                     => 'done',
+        captcha_login_enabled    => 'Activation in login form',
+        captcha_mail_enabled     => 'Activation in password reset by mail form',
+        captcha_register_enabled => 'Activation in register form',
+        captcha_size             => 'Size',
+        captchaStorage           => 'Captcha module name',
+        captchaStorageOptions    => 'Captcha module options',
+        CAS_authnLevel           => 'Authentication level',
+        CAS_CAFile               => 'CA file',
+        CAS_gateway              => 'Gateway authentication',
+        CAS_pgtFile              => 'PGT file',
+        CAS_proxiedServices      => 'Proxied services',
+        CAS_renew                => 'Renew authentication',
+        CAS_url                  => 'Server URL',
+        casAccessControlPolicy   => 'Access control policy',
+        casAttr                  => 'CAS login',
+        casParams                => 'CAS parameters',
+        casStorage               => 'CAS sessions module name',
+        casStorageOptions        => 'CAS sessions module options',
+        cda                      => 'Multiple domains',
+        checkXSS                 => 'Check XSS attacks',
+        clickHereToForce         => 'Click here to force',
+        choiceParams             => 'Choice parameters',
+        Configuration            => 'Configuration',
         confModuledeprecated =>
 'This module has been deprecated, set "forceUpload=1" in lemonldap-ng.ini to use it',
         confSaved                       => 'Configuration saved',
@@ -132,10 +148,18 @@ sub en {
         error                           => 'Error',
         exportedAttr                    => 'SOAP exported attributes',
         exportedVars                    => 'Exported Variables',
+        facebookAppId                   => 'Facebook application ID',
+        facebookAppSecret               => 'Facebook application secret',
+        facebookAuthnLevel              => 'Authentication level',
+        facebookExportedVars            => 'Exported variables',
+        facebookParams                  => 'Facebook parameters',
         failedLoginNumber               => 'Number of registered failed logins',
         generalParameters               => 'General Parameters',
         globalStorage                   => 'Apache::Session module',
         globalStorageOptions            => 'Apache::Session module parameters',
+        googleAuthnLevel                => 'Authentication level',
+        googleExportedVars              => 'Exported variables',
+        googleParams                    => 'Google parameters',
         grantSessionRules               => 'Opening conditions',
         groups                          => 'Groups',
         headers                         => 'HTTP Headers',
@@ -166,6 +190,7 @@ sub en {
         ldapBase                        => 'Users search base',
         ldapChangePasswordAsUser        => 'Change as user',
         ldapConnection                  => 'Connection',
+        ldapExportedVars                => 'Exported variables',
         ldapFilters                     => 'Filters',
         LDAPFilter                      => 'Default filter',
         ldapGroupAttributeName          => 'Target attribute',
@@ -189,6 +214,8 @@ sub en {
         ldapTimeout                     => 'Timeout',
         ldapUsePasswordResetAttribute   => 'Use reset attribute',
         ldapVersion                     => 'Version',
+        localSessionStorage             => 'Cache module',
+        localSessionStorageOptions      => 'Cache module options',
         loginHistory                    => 'Login history',
         loginHistoryEnabled             => 'Activation',
         logoutServices                  => 'Logout forward',
@@ -236,6 +263,7 @@ sub en {
         nullParams                  => 'Null parameters',
         openIdAttr                  => 'OpenID login',
         openIdAuthnLevel            => 'Authentication level',
+        openIdExportedVars          => 'Exported variables',
         openIdIDPList               => 'Authorizated domains',
         openIdIssuerSecret          => 'Secret token',
         openIdParams                => 'OpenID parameters',
@@ -260,18 +288,23 @@ sub en {
         portal                      => 'URL',
         portalAntiFrame             => 'Anti frame protection',
         portalAutocomplete          => 'Auto complete',
+        portalButtons               => 'Buttons on login page',
+        portalCaptcha               => 'Captcha',
         portalCheckLogins           => 'Check last logins',
         portalCustomization         => 'Customization',
         portalDisplayAppslist       => 'Applications list',
         portalDisplayChangePassword => 'Password change',
         portalDisplayLoginHistory   => 'Login History',
         portalDisplayLogout         => 'Logout',
+        portalDisplayRegister       => 'Register new account',
         portalDisplayResetPassword  => 'Reset password',
         portalForceAuthn            => 'Force authentication',
         portalMenu                  => 'Menu',
         portalModules               => 'Modules activation',
         portalOpenLinkInNewWindow   => 'New window',
+        portalOther                 => 'Other',
         portalParams                => 'Portal',
+        portalPingInterval          => 'Ping Interval',
         portalRedirection           => 'Portal redirections',
         portalRequireOldPassword    => 'Require old password',
         portalSkin                  => 'Default Skin',
@@ -286,6 +319,12 @@ sub en {
         radiusServer                => 'Server hostname',
         randomPasswordRegexp        => 'Regexp for password generation',
         redirection                 => 'Handler redirections',
+        register                    => 'Register new account',
+        registerConfirmSubject      => 'Subject for confirmation mail',
+        registerDB                  => 'Module',
+        registerDoneSubject         => 'Subject for done mail',
+        registerTimeout             => 'Validity time of a register request',
+        registerUrl                 => 'Page URL',
         reloadUrls                  => 'Configuration reload',
         remoteCookieName            => 'Cookie name',
         remoteGlobalStorage         => 'Sessions module',
@@ -314,6 +353,7 @@ sub en {
         singleSession               => 'One session only by user',
         singleUserByIP              => 'One user by IP address',
         slaveAuthnLevel             => 'Authentication level',
+        slaveExportedVars           => 'Exported variables',
         slaveMasterIP               => 'Master\'s IP address',
         slaveParams                 => 'Slave parameters',
         slaveUserHeader             => "Header for user login",
@@ -357,12 +397,17 @@ sub en {
         useRedirectOnForbidden      => 'Redirect on forbidden',
         useSafeJail                 => 'Use Safe jail',
         variables                   => "Variables",
+        vhostAliases                => 'Aliases',
         vhostHttps                  => 'HTTPS',
         vhostMaintenance            => 'Maintenance mode',
         vhostOptions                => 'Options',
         vhostPort                   => 'Port',
         virtualHosts                => 'Virtual Hosts',
         warning                     => 'Warning',
+        webIDAuthnLevel             => 'Authentication level',
+        webIDExportedVars           => 'Exported variables',
+        webIDParams                 => 'WebID parameters',
+        webIDWhitelist              => 'WebID whitelist',
         whatToTrace                 => "REMOTE_USER",
         yubikeyAuthnLevel           => 'Authentication level',
         yubikeyClientID             => 'API client ID',
@@ -428,13 +473,16 @@ sub en {
         samlSPMetaDataOptionsAuthnResponse  => 'Authentication response',
         samlSPMetaDataOptionsSignature      => 'Signature',
         samlSPMetaDataOptionsSecurity       => 'Security',
-        samlServiceMetaData                 => 'SAML 2 Service',
-        samlEntityID                        => 'Entity Identifier',
-        samlOrganization                    => 'Organization',
-        samlOrganizationDisplayName         => 'Display Name',
-        samlOrganizationName                => 'Name',
-        samlOrganizationURL                 => 'URL',
-        samlSPSSODescriptor                 => 'Service Provider',
+        samlSPMetaDataOptionsEnableIDPInitiatedURL =>
+          'Enable use of IDP initiated URL',
+        samlSPMetaDataOptionsNameIDSessionKey => 'Force NameID session key',
+        samlServiceMetaData                   => 'SAML 2 Service',
+        samlEntityID                          => 'Entity Identifier',
+        samlOrganization                      => 'Organization',
+        samlOrganizationDisplayName           => 'Display Name',
+        samlOrganizationName                  => 'Name',
+        samlOrganizationURL                   => 'URL',
+        samlSPSSODescriptor                   => 'Service Provider',
         samlSPSSODescriptorAuthnRequestsSigned =>
           'Signed Authentication Request',
         samlSPSSODescriptorWantAssertionsSigned => 'Want Assertions Signed',
@@ -492,63 +540,84 @@ sub en {
         samlCommonDomainCookieDomain     => 'Common domain',
         samlCommonDomainCookieReader     => 'Reader URL',
         samlCommonDomainCookieWriter     => 'Writer URL',
+        samlRelayStateTimeout            => 'RelayState session timeout',
+        samlUseQueryStringSpecific       => 'Use specific query_string method',
     };
 }
 
 sub fr {
     use utf8;
     return {
-        _auth                  => 'Authentification',
-        _authChoice            => 'Choix d\'authentification',
-        _userDB                => 'Utilisateur',
-        _passwordDB            => 'Mot de passe',
-        _issuerDB              => 'Fournisseur',
-        _timezone              => 'Zone horaire',
-        _session_id            => 'Identifiant de session',
-        _url                   => "URL d'origine",
-        _user                  => 'Identifiant',
-        _password              => 'Mot de passe',
-        _utime                 => 'Tampon de la session',
-        _lastAuthnUTime        => 'Tampon d\'authentification ',
-        _idp                   => 'Identifiant d\'entité de l\'IDP',
-        _idpConfKey            => 'Clé de configuration de l\'IDP',
-        _samlToken             => ' Jeton SAML ',
-        _lassoSessionDump      => ' Dump session Lasso ',
-        _lassoIdentityDump     => 'Dump identité Lasso',
-        advancedParams         => 'Paramètres avancés',
-        apacheParams           => 'Paramètres Apache',
-        apacheAuthnLevel       => 'Niveau d\'authentification',
-        applicationList        => 'Catégories et applications',
-        attributesAndMacros    => 'Attributs et macros',
-        authChoiceModules      => 'Modules autorisés',
-        authChoiceParam        => 'Parmètre de l\'URL',
-        authentication         => "Module d'authentification",
-        authenticationLevel    => 'Niveau d\'authentification',
-        authenticationTitle    => 'Authentification',
-        AuthLDAPFilter         => 'Filtre d\'authentification',
-        authParams             => "Modules d'authentification",
-        dbiAuthChain           => 'Chaîne',
-        dbiAuthLoginCol        => 'Champ identifiant',
-        dbiAuthnLevel          => 'Niveau d\'authentification',
-        dbiAuthPassword        => 'Mot de passe',
-        dbiAuthPasswordCol     => 'Champ mot de passe',
-        dbiAuthPasswordHash    => 'Schéma de hachage',
-        dbiAuthTable           => 'Table authentification',
-        dbiAuthUser            => 'Utilisateur',
-        dbiConnection          => 'Connexion',
-        dbiConnectionAuth      => 'Authentification',
-        dbiConnectionUser      => 'Utilisateurs',
-        dbiParams              => 'Paramètres DBI',
-        dbiPassword            => 'Mot de passe',
-        dbiPasswordMailCol     => 'Champ mail',
-        dbiSchema              => 'Schéma',
-        dbiUserChain           => 'Chaîne',
-        dbiUserPassword        => 'Mot de passe',
-        dbiUserTable           => 'Table des utilisateurs',
-        dbiUserUser            => 'Utilisateur',
-        deleteNotification     => 'Marquer la notification comme validée',
-        deleteSession          => 'Effacer la session',
-        done                   => 'validée',
+        _auth                    => 'Authentification',
+        _authChoice              => 'Choix d\'authentification',
+        _userDB                  => 'Utilisateur',
+        _passwordDB              => 'Mot de passe',
+        _issuerDB                => 'Fournisseur',
+        _timezone                => 'Zone horaire',
+        _session_id              => 'Identifiant de session',
+        _url                     => "URL d'origine",
+        _user                    => 'Identifiant',
+        _password                => 'Mot de passe',
+        _utime                   => 'Tampon de la session',
+        _lastAuthnUTime          => 'Tampon d\'authentification ',
+        _idp                     => 'Identifiant d\'entité de l\'IDP',
+        _idpConfKey              => 'Clé de configuration de l\'IDP',
+        _samlToken               => ' Jeton SAML ',
+        _lassoSessionDump        => ' Dump session Lasso ',
+        _lassoIdentityDump       => 'Dump identité Lasso',
+        advancedParams           => 'Paramètres avancés',
+        apacheParams             => 'Paramètres Apache',
+        apacheAuthnLevel         => 'Niveau d\'authentification',
+        applicationList          => 'Catégories et applications',
+        attributesAndMacros      => 'Attributs et macros',
+        authChoiceModules        => 'Modules autorisés',
+        authChoiceParam          => 'Parmètre de l\'URL',
+        authentication           => "Module d'authentification",
+        authenticationLevel      => 'Niveau d\'authentification',
+        authenticationTitle      => 'Authentification',
+        AuthLDAPFilter           => 'Filtre d\'authentification',
+        authParams               => "Modules d'authentification",
+        browserIdAuthnLevel      => "Niveau d'authentification",
+        browserIdAutoLogin       => "Authentification automatique",
+        browserIdBackgroundColor => "Couleur d'arrière plan",
+        browserIdParams          => "Paramètres BrowserID",
+        browserIdSiteLogo        => "Logo du site",
+        browserIdSiteName        => "Nom du site",
+        browserIdVerificationURL => "Adresse de vérification",
+        dbiAuthChain             => 'Chaîne',
+        dbiAuthLoginCol          => 'Champ identifiant',
+        dbiAuthnLevel            => 'Niveau d\'authentification',
+        dbiAuthPassword          => 'Mot de passe',
+        dbiAuthPasswordCol       => 'Champ mot de passe',
+        dbiAuthPasswordHash      => 'Schéma de hachage',
+        dbiAuthTable             => 'Table authentification',
+        dbiAuthUser              => 'Utilisateur',
+        dbiConnection            => 'Connexion',
+        dbiConnectionAuth        => 'Authentification',
+        dbiConnectionUser        => 'Utilisateurs',
+        dbiExportedVars          => 'Variables exportées',
+        dbiParams                => 'Paramètres DBI',
+        dbiPassword              => 'Mot de passe',
+        dbiPasswordMailCol       => 'Champ mail',
+        dbiSchema                => 'Schéma',
+        dbiUserChain             => 'Chaîne',
+        dbiUserPassword          => 'Mot de passe',
+        dbiUserTable             => 'Table des utilisateurs',
+        dbiUserUser              => 'Utilisateur',
+        deleteNotification       => 'Marquer la notification comme validée',
+        deleteSession            => 'Effacer la session',
+        demoExportedVars         => 'Variables exportées',
+        demoParams               => 'Paramètres démonstration',
+        done                     => 'validée',
+        captcha_login_enabled =>
+          "Activation dans le formulaire d'authentification",
+        captcha_mail_enabled =>
+          'Activation dans le formulaire de réinitialisation par mail',
+        captcha_register_enabled =>
+          'Activation dans le formulaire de création de compte',
+        captcha_size           => 'Taille',
+        captchaStorage         => 'Nom du module de stockage',
+        captchaStorageOptions  => 'Options du module de stockage',
         CAS_authnLevel         => 'Niveau d\'authentification',
         CAS_CAFile             => 'Fichier d\'AC',
         CAS_gateway            => 'Authentification transparente',
@@ -582,10 +651,18 @@ sub fr {
         error          => 'Erreur',
         exportedAttr   => 'Attributs exportés par le portail (SOAP)',
         exportedVars   => 'Attributs à exporter',
+        facebookAppId  => 'ID de l\'application Facebook',
+        facebookAppSecret      => 'Secret de l\'application Facebook',
+        facebookExportedVars   => 'Variables exportées',
+        facebookAuthnLevel     => 'Niveau d\'authentification',
+        facebookParams         => 'Paramètres Facebook',
         failedLoginNumber      => 'Nombre d\'échecs de connexion mémorisés',
         generalParameters      => 'Paramètres généraux',
         globalStorage          => 'Module Apache::Session',
         globalStorageOptions   => 'Paramètres du module Apache::Session',
+        googleAuthnLevel       => 'Niveau d\'authentification',
+        googleExportedVars     => 'Variables exportées',
+        googleParams           => 'Paramètres Google',
         grantSessionRules      => "Conditions d'ouverture",
         groups                 => 'Groupes',
         headers                => 'En-têtes HTTP',
@@ -616,6 +693,7 @@ sub fr {
         ldapBase                        => 'Base de recherche des utilisateurs',
         ldapChangePasswordAsUser        => 'Changement en tant qu\'utilisateur',
         ldapConnection                  => 'Connexion',
+        ldapExportedVars                => 'Variables exportées',
         ldapFilters                     => 'Filtres',
         LDAPFilter                      => 'Filtre par défaut',
         ldapGroupAttributeName          => 'Attribut cible',
@@ -639,20 +717,22 @@ sub fr {
         ldapTimeout     => 'Temps maximum d\'inactivité',
         ldapUsePasswordResetAttribute =>
           'Utiliser l\'attribut de réinitialisation',
-        ldapVersion         => 'Version',
-        loginHistory        => 'Historique des connexions',
-        loginHistoryEnabled => 'Activation',
-        logoutServices      => 'Transfert de la déconnexion',
-        logParams           => 'Journalisation',
-        macros              => 'Macros',
-        mailBody            => 'Contenu du message de succès',
-        mailCharset         => 'Charset',
-        mailConfirmBody     => 'Contenu du message de confirmation',
-        mailConfirmSubject  => 'Sujet du message de confirmation',
-        mailContent         => 'Contenu du mail',
-        mailFrom            => 'Expéditeur du message',
-        mailHeaders         => 'En-têtes du mail',
-        mailLDAPFilter      => 'Filtre mail',
+        ldapVersion                => 'Version',
+        localSessionStorage        => 'Module de cache',
+        localSessionStorageOptions => 'Paramètres du module de cache',
+        loginHistory               => 'Historique des connexions',
+        loginHistoryEnabled        => 'Activation',
+        logoutServices             => 'Transfert de la déconnexion',
+        logParams                  => 'Journalisation',
+        macros                     => 'Macros',
+        mailBody                   => 'Contenu du message de succès',
+        mailCharset                => 'Charset',
+        mailConfirmBody            => 'Contenu du message de confirmation',
+        mailConfirmSubject         => 'Sujet du message de confirmation',
+        mailContent                => 'Contenu du mail',
+        mailFrom                   => 'Expéditeur du message',
+        mailHeaders                => 'En-têtes du mail',
+        mailLDAPFilter             => 'Filtre mail',
         mailOnPasswordChange =>
           "Envoi d'un mail quand le mot de passe est changé",
         mailOther      => 'Autres',
@@ -691,6 +771,7 @@ sub fr {
         nullParams                  => 'Paramètres Null',
         openIdAttr                  => 'Identifiant OpenID',
         openIdAuthnLevel            => 'Niveau d\'authentification',
+        openIdExportedVars          => 'Variables exportées',
         openIdIDPList               => 'Domaines autorisés',
         openIdIssuerSecret          => 'Jeton secret',
         openIdParams                => 'Paramètres OpenID',
@@ -715,18 +796,23 @@ sub fr {
         portal                      => 'URL',
         portalAntiFrame             => 'Protection anti frame',
         portalAutocomplete          => 'Auto complétion',
+        portalButtons               => 'Boutons sur la page de connexion',
+        portalCaptcha               => 'Captcha',
         portalCheckLogins           => 'Vérifier l\'historique',
         portalCustomization         => 'Personnalisation',
         portalDisplayAppslist       => 'Liste des applications',
         portalDisplayChangePassword => 'Changement de mot de passe',
         portalDisplayLoginHistory   => 'Historique des connexions',
         portalDisplayLogout         => 'Déconnexion',
+        portalDisplayRegister       => 'Création d\'un nouveau compte',
         portalDisplayResetPassword  => 'Réinitialisation de mot de passe',
         portalForceAuthn            => 'Authentication forcée',
         portalMenu                  => 'Menu',
         portalModules               => 'Modules',
         portalOpenLinkInNewWindow   => 'Nouvelle fenêtre',
+        portalOther                 => 'Autres',
         portalParams                => 'Portail',
+        portalPingInterval          => 'Interval du ping',
         portalRedirection           => 'Redirections du portail',
         portalRequireOldPassword    => 'Ancien mot de passe requis',
         portalSkin                  => 'Thème visuel par défaut',
@@ -742,6 +828,12 @@ sub fr {
         randomPasswordRegexp =>
           'Expression regulière pour la génération des mots de passe',
         redirection                 => 'Redirections du Handler',
+        register                    => 'Créer un nouveau compte',
+        registerConfirmSubject      => 'Sujet du mail de confirmation',
+        registerDB                  => 'Module',
+        registerDoneSubject         => 'Sujet du mail de prise en compte',
+        registerTimeout             => 'Durée de validité de la requête',
+        registerUrl                 => 'URL de la page',
         reloadUrls                  => 'Mise à jour de la configuration',
         remoteCookieName            => 'Nom du cookie',
         remoteGlobalStorage         => 'Module des sessions',
@@ -770,6 +862,7 @@ sub fr {
         singleSession      => 'Une seule session par utilisateur',
         singleUserByIP     => 'Un seul utilisateur par IP',
         slaveAuthnLevel    => 'Niveau d\'authentification',
+        slaveExportedVars  => 'Variables exportées',
         slaveMasterIP      => 'IP accréditées',
         slaveParams        => 'Paramètres Slave',
         slaveUserHeader    => "En-tête identifiant l'utilisateur",
@@ -813,12 +906,17 @@ sub fr {
         useRedirectOnForbidden => 'Redirection pour les accès interdits',
         useSafeJail            => 'Utiliser la cage Safe',
         variables              => "Variables",
+        vhostAliases           => 'Alias',
         vhostHttps             => 'HTTPS',
         vhostMaintenance       => 'Mode maintenance',
         vhostOptions           => 'Options',
         vhostPort              => 'Port',
         virtualHosts           => 'Hôtes virtuels',
         warning                => 'Attention',
+        webIDAuthnLevel        => 'Niveau d\'authentification',
+        webIDExportedVars      => 'Variables exportées',
+        webIDParams            => 'Paramètres WebID',
+        webIDWhitelist         => 'Liste blanche WebID',
         whatToTrace            => "REMOTE_USER",
         yubikeyAuthnLevel      => "Niveau d'authentification",
         yubikeyClientID        => "Identifiant client de l'API",
@@ -886,13 +984,17 @@ sub fr {
         samlSPMetaDataOptionsAuthnResponse  => 'Réponse d\'authentification',
         samlSPMetaDataOptionsSignature      => 'Signature',
         samlSPMetaDataOptionsSecurity       => 'Sécurité',
-        samlServiceMetaData                 => 'Service SAML 2',
-        samlEntityID                        => 'Identifiant d\'entité',
-        samlOrganization                    => 'Organisation',
-        samlOrganizationDisplayName         => 'Nom affiché',
-        samlOrganizationName                => 'Nom',
-        samlOrganizationURL                 => 'URL',
-        samlSPSSODescriptor                 => 'Fournisseur de service',
+        samlSPMetaDataOptionsEnableIDPInitiatedURL =>
+          "Autoriser l'utilisation d'URL SSO initié par l'IDP",
+        samlSPMetaDataOptionsNameIDSessionKey =>
+          "Forcer la clé de session NameID",
+        samlServiceMetaData         => 'Service SAML 2',
+        samlEntityID                => 'Identifiant d\'entité',
+        samlOrganization            => 'Organisation',
+        samlOrganizationDisplayName => 'Nom affiché',
+        samlOrganizationName        => 'Nom',
+        samlOrganizationURL         => 'URL',
+        samlSPSSODescriptor         => 'Fournisseur de service',
         samlSPSSODescriptorAuthnRequestsSigned =>
           'Requêtes d\'authentification signées',
         samlSPSSODescriptorWantAssertionsSigned =>
@@ -957,6 +1059,9 @@ sub fr {
         samlCommonDomainCookieDomain     => 'Domaine commun',
         samlCommonDomainCookieReader     => 'URL de lecture',
         samlCommonDomainCookieWriter     => 'URL d\'écriture',
+        samlRelayStateTimeout => 'Durée de vie d\'une session RelayState',
+        samlUseQueryStringSpecific =>
+          "Utilisation d'une fonction spécifique pour query_string",
     };
 }
 
